==> typo3-6.0.4.tbz: www/typo3_src-6.0.4/typo3/sysext/frontend/Classes/Page/PageRepositoryGetRecordOverlayHookInterface.php <==
<?php
namespace TYPO3\CMS\Frontend\Page;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2010-2011 Tolleiv Nietsch <nietsch@aoemedia.de>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *  A copy is found in the textfile GPL.txt and important notices to the license
 *  from the author is found in LICENSE.txt distributed with these scripts.
 *
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/
/**
 * interface for classes which hook into t3lib_pageSelect
 *
 * @author Tolleiv Nietsch <nietsch@aoemedia.de>
 */
interface PageRepositoryGetRecordOverlayHookInterface
{
	/**
	 * Enables to preprocess a record overlay
	 *
	 * @param string $table
	 * @param array $row
	 * @param integer $sys_language_content
	 * @param string $OLmode
	 * @param \TYPO3\CMS\Frontend\Page\PageRepository $parent
	 */
	public function getRecordOverlay_preProcess($table, &$row, &$sys_language_content, $OLmode, \TYPO3\CMS\Frontend\Page\PageRepository $parent);

	/**
	 * Enables to postprocess a record overlay
	 *
	 * @param string $table
	 * @param array $row
	 * @param integer $sys_language_content
	 * @param string $OLmode
	 * @param \TYPO3\CMS\Frontend\Page\PageRepository $parent
	 */
	public function getRecordOverlay_postProcess($table, &$row, &$sys_language_content, $OLmode, \TYPO3\CMS\Frontend\Page\PageRepository $parent);

}

?>

==> typo3-6.1.0.tbz: www/typo3_src-6.1.0/typo3/sysext/frontend/Classes/Page/PageRepositoryGetRecordOverlayHookInterface.php <==
<?php
namespace TYPO3\CMS\Frontend\Page;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2010-2013 Tolleiv Nietsch <nietsch@aoemedia.de>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *  A copy is found in the textfile GPL.txt and important notices to the license
 *  from the author is found in LICENSE.txt distributed with these scripts.
 *
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * Interface for classes which hook into \TYPO3\CMS\Frontend\Page\PageRepository
 *
 * @author Tolleiv Nietsch <nietsch@aoemedia.de>
 */
interface PageRepositoryGetRecordOverlayHookInterface {
	/**
	 * Enables to preprocess a record overlay
	 *
	 * @param string $table
	 * @param array $row
	 * @param integer $sys_language_content
	 * @param string $OLmode
	 * @param \TYPO3\CMS\Frontend\Page\PageRepository $parent
	 */
	public function getRecordOverlay_preProcess($table, &$row, &$sys_language_content, $OLmode, \TYPO3\CMS\Frontend\Page\PageRepository $parent);

	/**
	 * Enables to postprocess a record overlay
	 *
	 * @param string $table
	 * @param array $row
	 * @param integer $sys_language_content
	 * @param string $OLmode
	 * @param \TYPO3\CMS\Frontend\Page\PageRepository $parent
	 */
	public function getRecordOverlay_postProcess($table, &$row, &$sys_language_content, $OLmode, \TYPO3\CMS\Frontend\Page\PageRepository $parent);

}

?>
